import { type BlockDefinition, type CompositeBlockTypeDefinition, type PipelineDefinition } from '@jvalue/jayvee-language-server';
import { type ExecutionContext } from '../execution-context';
import { type Logger } from '../logging/logger';
import { type IOTypeImplementation } from '../types';
import * as R from './execution-result';
export interface ExecutionOrderItem {
    block: BlockDefinition;
    value: IOTypeImplementation | null;
}
/**
 * Executes an ordered list of blocks in sequence, using outputs from previous blocks as inputs for downstream blocks.
 *
 * @param executionContext The context the blocks are executed in, e.g., a pipeline or composite block
 * @param executionOrder An ordered list of blocks so that blocks that need inputs are after blocks that produce these inputs
 * @param initialInputValue An initial input that was produced outside of this block chain, e.g., as input to a composite block
 *
 * @returns The ordered blocks and their produced outputs or an error on failure
 */
export declare function executeBlocks(executionContext: ExecutionContext, pipesContainer: CompositeBlockTypeDefinition | PipelineDefinition, initialInputValue?: IOTypeImplementation | undefined): Promise<R.Result<ExecutionOrderItem[]>>;
export declare function executeBlock(inputValue: IOTypeImplementation | null, block: BlockDefinition, executionContext: ExecutionContext): Promise<R.Result<IOTypeImplementation | null>>;
export declare function logExecutionDuration(startTime: Date, logger: Logger): void;
