import { IOType, type InternalValueRepresentation, type ValueType } from '@jvalue/jayvee-language-server';
import { type IOTypeImplementation, type IoTypeVisitor } from './io-type-implementation';
export interface TableColumn<T extends InternalValueRepresentation = InternalValueRepresentation> {
    values: T[];
    valueType: ValueType;
}
export type TableRow = Record<string, InternalValueRepresentation>;
/**
 * Invariant: the shape of the table is always a rectangle.
 * This means all columns must have the same size.
 */
export declare class Table implements IOTypeImplementation<IOType.TABLE> {
    readonly ioType = IOType.TABLE;
    private numberOfRows;
    private columns;
    constructor(numberOfRows?: number);
    addColumn(name: string, column: TableColumn): void;
    /**
     * Tries to add a new row to this table.
     * NOTE: This method will only add the row if the table has at least one column!
     * @param row data of this row for each column
     */
    addRow(row: TableRow): void;
    dropRow(rowId: number): void;
    dropRows(rowIds: number[]): void;
    getNumberOfRows(): number;
    getNumberOfColumns(): number;
    hasColumn(name: string): boolean;
    getColumns(): ReadonlyMap<string, TableColumn>;
    getColumn(name: string): TableColumn | undefined;
    getRow(rowId: number): Map<string, InternalValueRepresentation>;
    static generateDropTableStatement(tableName: string): string;
    generateInsertValuesStatement(tableName: string): string;
    generateCreateTableStatement(tableName: string): string;
    clone(): Table;
    acceptVisitor<R>(visitor: IoTypeVisitor<R>): R;
}
