export type BackoffStrategyHandle = 'exponential' | 'linear';
export declare function isBackoffStrategyHandle(v: unknown): v is BackoffStrategyHandle;
export declare function createBackoffStrategy(handle: BackoffStrategyHandle, backoffMilliseconds: number): BackoffStrategy;
export interface BackoffStrategy {
    /**
     * Calculates the backoff interval in milliseconds.
     * @param retry the number of the current retry, starts counting with 1
     */
    getBackoffMilliseconds(retry: number): number;
}
/**
 * Strategy for exponential backoffs.
 * Uses seconds as unit for calculating the exponent.
 */
export declare class ExponentialBackoffStrategy implements BackoffStrategy {
    private initialBackoffMilliseconds;
    constructor(initialBackoffMilliseconds: number);
    getBackoffMilliseconds(retry: number): number;
}
/**
 * Strategy for linear backoffs.
 */
export declare class LinearBackoffStrategy implements BackoffStrategy {
    private backoffMilliseconds;
    constructor(backoffMilliseconds: number);
    getBackoffMilliseconds(): number;
}
