import { type BinaryExpression, type TernaryExpression, type UnaryExpression } from '../generated/ast';
import { type ValueTypeProvider, type WrapperFactoryProvider } from '../wrappers';
import { AdditionOperatorEvaluator } from './evaluators/addition-operator-evaluator';
import { AndOperatorEvaluator } from './evaluators/and-operator-evaluator';
import { CeilOperatorEvaluator } from './evaluators/ceil-operator-evaluator';
import { DivisionOperatorEvaluator } from './evaluators/division-operator-evaluator';
import { EqualityOperatorEvaluator } from './evaluators/equality-operator-evaluator';
import { FloorOperatorEvaluator } from './evaluators/floor-operator-evaluator';
import { GreaterEqualOperatorEvaluator } from './evaluators/greater-equal-operator-evaluator';
import { GreaterThanOperatorEvaluator } from './evaluators/greater-than-operator-evaluator';
import { InOperatorEvaluator } from './evaluators/in-operator-evaluator';
import { InequalityOperatorEvaluator } from './evaluators/inequality-operator-evaluator';
import { LessEqualOperatorEvaluator } from './evaluators/less-equal-operator-evaluator';
import { LessThanOperatorEvaluator } from './evaluators/less-than-operator-evaluator';
import { LowercaseOperatorEvaluator } from './evaluators/lowercase-operator-evaluator';
import { MatchesOperatorEvaluator } from './evaluators/matches-operator-evaluator';
import { MinusOperatorEvaluator } from './evaluators/minus-operator-evaluator';
import { ModuloOperatorEvaluator } from './evaluators/modulo-operator-evaluator';
import { MultiplicationOperatorEvaluator } from './evaluators/multiplication-operator-evaluator';
import { NotOperatorEvaluator } from './evaluators/not-operator-evaluator';
import { OrOperatorEvaluator } from './evaluators/or-operator-evaluator';
import { AsBooleanOperatorEvaluator, AsDecimalOperatorEvaluator, AsIntegerOperatorEvaluator, AsTextOperatorEvaluator } from './evaluators/parse-operators-evaluators';
import { PlusOperatorEvaluator } from './evaluators/plus-operator-evaluator';
import { PowOperatorEvaluator } from './evaluators/pow-operator-evaluator';
import { ReplaceOperatorEvaluator } from './evaluators/replace-operator-evaluator';
import { RootOperatorEvaluator } from './evaluators/root-operator-evaluator';
import { RoundOperatorEvaluator } from './evaluators/round-operator-evaluator';
import { SqrtOperatorEvaluator } from './evaluators/sqrt-operator-evaluator';
import { SubtractionOperatorEvaluator } from './evaluators/subtraction-operator-evaluator';
import { UppercaseOperatorEvaluator } from './evaluators/uppercase-operator-evaluator';
import { XorOperatorEvaluator } from './evaluators/xor-operator-evaluator';
import { type OperatorEvaluator } from './operator-evaluator';
import { type BinaryOperatorTypeComputer, type TernaryOperatorTypeComputer, type UnaryOperatorTypeComputer } from './operator-type-computer';
import { type BinaryExpressionOperator, type TernaryExpressionOperator, type UnaryExpressionOperator } from './operator-types';
import { BasicArithmeticOperatorTypeComputer } from './type-computers/basic-arithmetic-operator-type-computer';
import { DivisionOperatorTypeComputer } from './type-computers/division-operator-type-computer';
import { EqualityOperatorTypeComputer } from './type-computers/equality-operator-type-computer';
import { ExponentialOperatorTypeComputer } from './type-computers/exponential-operator-type-computer';
import { InOperatorTypeComputer } from './type-computers/in-operator-type-computer';
import { IntegerConversionOperatorTypeComputer } from './type-computers/integer-conversion-operator-type-computer';
import { LogicalOperatorTypeComputer } from './type-computers/logical-operator-type-computer';
import { MatchesOperatorTypeComputer } from './type-computers/matches-operator-type-computer';
import { NotOperatorTypeComputer } from './type-computers/not-operator-type-computer';
import { AsBooleanOperatorTypeComputer, AsDecimalOperatorTypeComputer, AsIntegerOperatorTypeComputer, AsTextOperatorTypeComputer } from './type-computers/parse-opterators-type-computer';
import { RelationalOperatorTypeComputer } from './type-computers/relational-operator-type-computer';
import { ReplaceOperatorTypeComputer } from './type-computers/replace-operator-type-computer';
import { SignOperatorTypeComputer } from './type-computers/sign-operator-type-computer';
import { SqrtOperatorTypeComputer } from './type-computers/sqrt-operator-type-computer';
import { StringTransformTypeComputer } from './type-computers/string-transform-type-computer';
export interface OperatorEvaluatorRegistry {
    unary: Record<UnaryExpressionOperator, OperatorEvaluator<UnaryExpression>>;
    binary: Record<BinaryExpressionOperator, OperatorEvaluator<BinaryExpression>>;
    ternary: Record<TernaryExpressionOperator, OperatorEvaluator<TernaryExpression>>;
}
export interface OperatorTypeComputerRegistry {
    unary: Record<UnaryExpressionOperator, UnaryOperatorTypeComputer>;
    binary: Record<BinaryExpressionOperator, BinaryOperatorTypeComputer>;
    ternary: Record<TernaryExpressionOperator, TernaryOperatorTypeComputer>;
}
export declare class DefaultOperatorEvaluatorRegistry implements OperatorEvaluatorRegistry {
    private readonly valueTypeProvider;
    unary: {
        not: NotOperatorEvaluator;
        '+': PlusOperatorEvaluator;
        '-': MinusOperatorEvaluator;
        sqrt: SqrtOperatorEvaluator;
        floor: FloorOperatorEvaluator;
        ceil: CeilOperatorEvaluator;
        round: RoundOperatorEvaluator;
        lowercase: LowercaseOperatorEvaluator;
        uppercase: UppercaseOperatorEvaluator;
        asDecimal: AsDecimalOperatorEvaluator;
        asInteger: AsIntegerOperatorEvaluator;
        asBoolean: AsBooleanOperatorEvaluator;
        asText: AsTextOperatorEvaluator;
    };
    binary: {
        pow: PowOperatorEvaluator;
        root: RootOperatorEvaluator;
        '*': MultiplicationOperatorEvaluator;
        '/': DivisionOperatorEvaluator;
        '%': ModuloOperatorEvaluator;
        '+': AdditionOperatorEvaluator;
        '-': SubtractionOperatorEvaluator;
        matches: MatchesOperatorEvaluator;
        in: InOperatorEvaluator;
        '<': LessThanOperatorEvaluator;
        '<=': LessEqualOperatorEvaluator;
        '>': GreaterThanOperatorEvaluator;
        '>=': GreaterEqualOperatorEvaluator;
        '==': EqualityOperatorEvaluator;
        '!=': InequalityOperatorEvaluator;
        xor: XorOperatorEvaluator;
        and: AndOperatorEvaluator;
        or: OrOperatorEvaluator;
    };
    ternary: {
        replace: ReplaceOperatorEvaluator;
    };
    constructor(valueTypeProvider: ValueTypeProvider);
}
export declare class DefaultOperatorTypeComputerRegistry implements OperatorTypeComputerRegistry {
    private readonly valueTypeProvider;
    private readonly wrapperFactories;
    unary: {
        not: NotOperatorTypeComputer;
        '+': SignOperatorTypeComputer;
        '-': SignOperatorTypeComputer;
        sqrt: SqrtOperatorTypeComputer;
        floor: IntegerConversionOperatorTypeComputer;
        ceil: IntegerConversionOperatorTypeComputer;
        round: IntegerConversionOperatorTypeComputer;
        lowercase: StringTransformTypeComputer;
        uppercase: StringTransformTypeComputer;
        asDecimal: AsDecimalOperatorTypeComputer;
        asInteger: AsIntegerOperatorTypeComputer;
        asBoolean: AsBooleanOperatorTypeComputer;
        asText: AsTextOperatorTypeComputer;
    };
    binary: {
        pow: ExponentialOperatorTypeComputer;
        root: ExponentialOperatorTypeComputer;
        '*': BasicArithmeticOperatorTypeComputer;
        '/': DivisionOperatorTypeComputer;
        '%': DivisionOperatorTypeComputer;
        '+': BasicArithmeticOperatorTypeComputer;
        '-': BasicArithmeticOperatorTypeComputer;
        matches: MatchesOperatorTypeComputer;
        in: InOperatorTypeComputer;
        '<': RelationalOperatorTypeComputer;
        '<=': RelationalOperatorTypeComputer;
        '>': RelationalOperatorTypeComputer;
        '>=': RelationalOperatorTypeComputer;
        '==': EqualityOperatorTypeComputer;
        '!=': EqualityOperatorTypeComputer;
        xor: LogicalOperatorTypeComputer;
        and: LogicalOperatorTypeComputer;
        or: LogicalOperatorTypeComputer;
    };
    ternary: {
        replace: ReplaceOperatorTypeComputer;
    };
    constructor(valueTypeProvider: ValueTypeProvider, wrapperFactories: WrapperFactoryProvider);
}
