import { type AstNode } from 'langium';
import { type ValidationContext } from '../../../validation/validation-context';
import { type EvaluationContext } from '../../expressions/evaluation-context';
import { type InternalValueRepresentation } from '../../expressions/internal-value-representation';
import { type PropertyAssignment, type PropertyBody } from '../../generated/ast';
import { type AstNodeWrapper } from '../ast-node-wrapper';
import { type ValueType } from '../value-type';
export interface PropertySpecification<I extends InternalValueRepresentation = InternalValueRepresentation> {
    type: ValueType<I>;
    defaultValue?: I;
    validation?: (property: PropertyAssignment, validationContext: ValidationContext, evaluationContext: EvaluationContext) => void;
    docs?: PropertyDocs;
}
export interface ExampleDoc {
    code: string;
    description: string;
}
export interface PropertyDocs {
    description?: string;
    examples?: ExampleDoc[];
    validation?: string;
}
export declare abstract class TypedObjectWrapper<N extends AstNode = AstNode> implements AstNodeWrapper<N> {
    readonly astNode: N;
    readonly type: string;
    private readonly properties;
    private readonly validation?;
    protected constructor(astNode: N, type: string, properties: Record<string, PropertySpecification>, validation?: ((property: PropertyBody, validationContext: ValidationContext, evaluationContext: EvaluationContext) => void) | undefined);
    validate(propertyBody: PropertyBody, validationContext: ValidationContext, evaluationContext: EvaluationContext): void;
    getPropertySpecification(name: string | undefined): PropertySpecification | undefined;
    getPropertySpecifications(): Record<string, PropertySpecification>;
    hasPropertySpecification(name: string): boolean;
    getMissingRequiredPropertyNames(presentPropertyNames?: string[]): string[];
    getPropertyNames(kind?: 'optional' | 'required' | undefined, excludeNames?: string[]): string[];
}
