import { type AstNode, DocumentCache, type LangiumDocument, type LangiumDocuments, URI } from 'langium';
import { type ExportDetails } from '../ast';
import { type ExportableElement, type ImportDefinition, type JayveeModel } from '../ast/generated/ast';
import { type JayveeServices } from '../jayvee-module';
export interface ImportDetails {
    element: ExportableElement;
    importName: string;
}
export declare function isImportDetails(obj: any): obj is ImportDetails;
export declare class JayveeImportResolver {
    protected readonly documents: LangiumDocuments;
    protected readonly availableElementsPerDocumentCache: DocumentCache<string, ExportDetails[]>;
    constructor(services: JayveeServices);
    /**
     * Finds all import URIs that could not be resolved.
     */
    findUnresolvedImportURIs(model: JayveeModel): URI[];
    resolveImport(importDefinition: ImportDefinition): JayveeModel | undefined;
    resolveImportedDocument(importDefinition: ImportDefinition): LangiumDocument | undefined;
    resolveImportUri(importDefinition: ImportDefinition): URI | undefined;
    getImportedElements(model: JayveeModel): ImportDetails[];
    getImportedElementsFromDocument(importDefinition: ImportDefinition, importedDocument: LangiumDocument): ImportDetails[];
    getBuiltinElements(): ExportDetails[];
    getPublishedElementsFromDocument(document: LangiumDocument<AstNode>): ExportDetails[];
    /**
     * Gets all builtins' URIs
     */
    getBuiltinUris(): Set<string>;
}
